summary refs log tree commit diff
path: root/gnu/build
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/build')
-rw-r--r--gnu/build/linux-boot.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/gnu/build/linux-boot.scm b/gnu/build/linux-boot.scm
index 0fc90af6a3..c34a3f7c18 100644
--- a/gnu/build/linux-boot.scm
+++ b/gnu/build/linux-boot.scm
@@ -242,10 +242,10 @@ the last argument of `mknod'."
 is true, mount ROOT read-only and make it a union with a writable tmpfs using
 UNIONFS."
   (define (mark-as-not-killable pid)
-    ;; Tell the 'user-processes' dmd service that PID must be kept alive when
-    ;; shutting down.
-    (mkdir-p "/root/etc/dmd")
-    (let ((port (open-file "/root/etc/dmd/do-not-kill" "a")))
+    ;; Tell the 'user-processes' shepherd service that PID must be kept alive
+    ;; when shutting down.
+    (mkdir-p "/root/etc/shepherd")
+    (let ((port (open-file "/root/etc/shepherd/do-not-kill" "a")))
       (chmod port #o600)
       (write pid port)
       (newline port)